double GEMINI_FUEL_MASS_OAMS      = 420*KG;
const double  GEMINI_THRUST_MAN   = 45.35*KGF;
const double  GEMINI_THRUST_RETRO = 1159*KGF;
const double  GEMINI_THRUST_ATT   = 11.34*KGF;
const double  GEMINI_ISP          = 273*SEC;
THRUSTER_HANDLE thruster_oams[20];
PROPELLANT_HANDLE fuel_oams;

void CreateGeminiThrusters(VESSEL *vessel)
{

	VECTOR3 att_ref;
	VECTOR3 att_dir;
	const double R_ATTCOOR = .4;
	const double R_ATTZ = 2.75;
	const double R_ATTWIDTH=.05;
	const double R_ATTHEIGHT=1;
	const double R_RCSOFFSET=.2;

	const double O_ATTCOOR = 1.096;
	const double O_ATTZ = -2.25;
	const double O_TRANCOOR = 1.2;
	const double O_TRANZ= 0;
	const double O_ATTWIDTH= .02;
	const double O_ATTHEIGHT= 1;
	const double O_TRANWIDTH=.05;
	const double O_TRANHEIGHT=1;

	vessel->ClearPropellantResources();
	vessel->ClearThrusterDefinitions();

	fuel_oams = vessel->CreatePropellantResource(GEMINI_FUEL_MASS_OAMS);

	att_ref= _V(-O_ATTCOOR,O_ATTCOOR,O_ATTZ);
	att_dir = _V(0,-1,0);
	thruster_oams[0] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[0], O_ATTHEIGHT,O_ATTWIDTH);

	thruster_oams[16] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[16], O_ATTHEIGHT,O_ATTWIDTH);


	att_ref= _V(O_ATTCOOR,O_ATTCOOR,O_ATTZ);
	att_dir = _V(0,-1,0);
	thruster_oams[1] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[1], O_ATTHEIGHT,O_ATTWIDTH);
	thruster_oams[17] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[17], O_ATTHEIGHT,O_ATTWIDTH);

	att_ref= _V(-O_ATTCOOR,O_ATTCOOR,O_ATTZ);
	att_dir = _V(1,0,0);
	thruster_oams[2] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[2], O_ATTHEIGHT,O_ATTWIDTH);

	att_ref= _V(-O_ATTCOOR,-O_ATTCOOR,O_ATTZ);
	att_dir = _V(1,0,0);
	thruster_oams[3] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);

	att_ref= _V(-O_ATTCOOR,-O_ATTCOOR,O_ATTZ);
	att_dir = _V(0,1,0);
	thruster_oams[4] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[4], O_ATTHEIGHT,O_ATTWIDTH);
	thruster_oams[18] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[18], O_ATTHEIGHT,O_ATTWIDTH);

	att_ref= _V(O_ATTCOOR,-O_ATTCOOR,O_ATTZ);
	att_dir = _V(0,1,0);
	thruster_oams[5] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[5], O_ATTHEIGHT,O_ATTWIDTH);
	thruster_oams[19] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[19], O_ATTHEIGHT,O_ATTWIDTH);

	att_ref= _V(O_ATTCOOR,O_ATTCOOR,O_ATTZ);
	att_dir = _V(-1,0,0);
	thruster_oams[6] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[6], O_ATTHEIGHT,O_ATTWIDTH);

	att_ref= _V(O_ATTCOOR,-O_ATTCOOR,O_ATTZ);
	att_dir = _V(-1,0,0);
	thruster_oams[7] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_ATT, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[7], O_ATTHEIGHT,O_ATTWIDTH);

	att_dir = _V(0,0,1);
	att_ref= _V(0,1.5,-2.25);
	thruster_oams[8] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_MAN, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[8], O_TRANHEIGHT,O_TRANWIDTH);

	att_ref= _V(0,-1.5,-2.25);
	thruster_oams[9] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_MAN, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[9], O_TRANHEIGHT,O_TRANWIDTH);

	att_dir = _V(0,0,-1);
	att_ref= _V(1.35,.2,.10);
	thruster_oams[10] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_RETRO, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[10], O_TRANHEIGHT,O_TRANWIDTH);

	att_ref= _V(-1.35,-.2,.10);
	thruster_oams[11] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_RETRO, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[11], O_TRANHEIGHT,O_TRANWIDTH);

	att_ref= _V(0,-O_TRANCOOR,O_TRANZ);
	att_dir = _V(0,1,0);
	thruster_oams[12] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_MAN, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[12], O_TRANHEIGHT,O_TRANWIDTH);

	//tran down
	att_ref= _V(0,O_TRANCOOR,O_TRANZ);
	att_dir = _V(0,-1,0);
	thruster_oams[13] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_MAN, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[13], O_TRANHEIGHT,O_TRANWIDTH);

	//tran left
	att_ref= _V(O_TRANCOOR,0,O_TRANZ);
	att_dir = _V(-1,0,0);
	thruster_oams[14] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_MAN, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[14], O_TRANHEIGHT,O_TRANWIDTH);

	//tran right
	att_ref= _V(-O_TRANCOOR,0,O_TRANZ);
	att_dir = _V(1,0,0);
	thruster_oams[15] = vessel->CreateThruster( att_ref, att_dir,
GEMINI_THRUST_MAN, fuel_oams, GEMINI_ISP, 0.0);
	vessel->AddExhaust(thruster_oams[15], O_TRANHEIGHT,O_TRANWIDTH);


	SetOAMS(vessel);

}

void SetOAMS(VESSEL *vessel)
{
	THRUSTER_HANDLE th_group[4];

	vessel->DelThrusterGroup(THGROUP_ATT_YAWLEFT);
	vessel->DelThrusterGroup(THGROUP_ATT_YAWRIGHT);
	vessel->DelThrusterGroup(THGROUP_ATT_BANKLEFT);
	vessel->DelThrusterGroup(THGROUP_ATT_BANKRIGHT);
	vessel->DelThrusterGroup(THGROUP_ATT_PITCHDOWN);
	vessel->DelThrusterGroup(THGROUP_RETRO);
	vessel->DelThrusterGroup(THGROUP_MAIN);
	vessel->DelThrusterGroup(THGROUP_ATT_LEFT);
	vessel->DelThrusterGroup(THGROUP_ATT_RIGHT);
	vessel->DelThrusterGroup(THGROUP_ATT_UP);
	vessel->DelThrusterGroup(THGROUP_ATT_DOWN);


	th_group[0] = thruster_oams[2];
	th_group[1] = thruster_oams[3];
	vessel->CreateThrusterGroup(th_group,2,THGROUP_ATT_YAWLEFT);

	th_group[0] = thruster_oams[6];
	th_group[1] = thruster_oams[7];
	vessel->CreateThrusterGroup(th_group,2,THGROUP_ATT_YAWRIGHT);

//Have to do this
	th_group[0] = thruster_oams[16];
	th_group[1] = thruster_oams[19];
	vessel->CreateThrusterGroup(th_group,2,THGROUP_ATT_BANKLEFT);

	th_group[0] = thruster_oams[17];
	th_group[1] = thruster_oams[18];
	vessel->CreateThrusterGroup(th_group,2,THGROUP_ATT_BANKRIGHT);
/*
// This Causes the problem pitch disabled
	th_group[0] = thruster_oams[0];
	th_group[1] = thruster_oams[5];
	vessel->CreateThrusterGroup(th_group,2,THGROUP_ATT_BANKLEFT);

	th_group[0] = thruster_oams[1];
	th_group[1] = thruster_oams[4];
	vessel->CreateThrusterGroup(th_group,2,THGROUP_ATT_BANKRIGHT)
*/

	th_group[0] = thruster_oams[0];
	th_group[1] = thruster_oams[1];
	vessel->CreateThrusterGroup(th_group,2,THGROUP_ATT_PITCHUP);

	th_group[0] = thruster_oams[4];
	th_group[1] = thruster_oams[5];
	vessel->CreateThrusterGroup(th_group,2,THGROUP_ATT_PITCHDOWN);


	th_group[0] = thruster_oams[10];
	th_group[1] = thruster_oams[11];
	vessel->CreateThrusterGroup(th_group,2,THGROUP_RETRO);

	th_group[0] = thruster_oams[8];
	th_group[1] = thruster_oams[9];
	vessel->CreateThrusterGroup(th_group,2,THGROUP_MAIN);

	th_group[0] = thruster_oams[14];
	vessel->CreateThrusterGroup(th_group,1,THGROUP_ATT_LEFT);

	th_group[0] = thruster_oams[15];
	vessel->CreateThrusterGroup(th_group,1,THGROUP_ATT_RIGHT);

	th_group[0] = thruster_oams[13];
	vessel->CreateThrusterGroup(th_group,1,THGROUP_ATT_UP);

	th_group[0] = thruster_oams[12];
	vessel->CreateThrusterGroup(th_group,1,THGROUP_ATT_DOWN);

}

